summaryrefslogtreecommitdiffstats
path: root/cc/scheduler_state_machine.h
diff options
context:
space:
mode:
authorenne@chromium.org <enne@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-10-19 21:22:42 +0000
committerenne@chromium.org <enne@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-10-19 21:22:42 +0000
commitc753e25a8b4366c44134a8c21b9ed3392bf48608 (patch)
treef378c8a762caccf60856a1670ae33dfd638b9453 /cc/scheduler_state_machine.h
parent503160f80568f024fa712e280bb1a4e1e6ca1ec3 (diff)
downloadchromium_src-c753e25a8b4366c44134a8c21b9ed3392bf48608.zip
chromium_src-c753e25a8b4366c44134a8c21b9ed3392bf48608.tar.gz
chromium_src-c753e25a8b4366c44134a8c21b9ed3392bf48608.tar.bz2
Revert "cc: Rename cc classes and members to match filenames"
This reverts commit 184fac5add06d5f4670fa6be4a4d3b39232d51bb. git-svn-id: svn://svn.chromium.org/chrome/trunk/src@163059 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'cc/scheduler_state_machine.h')
-rw-r--r--cc/scheduler_state_machine.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/cc/scheduler_state_machine.h b/cc/scheduler_state_machine.h
index 782c084..092231f 100644
--- a/cc/scheduler_state_machine.h
+++ b/cc/scheduler_state_machine.h
@@ -11,7 +11,7 @@
namespace cc {
// The SchedulerStateMachine decides how to coordinate main thread activites
// like painting/running javascript with rendering and input activities on the
// impl thread.
//
@@ -21,9 +21,9 @@ namespace cc {
//
// The scheduler seperates "what to do next" from the updating of its internal state to
// make testing cleaner.
-class SchedulerStateMachine {
+class CCSchedulerStateMachine {
public:
- SchedulerStateMachine();
+ CCSchedulerStateMachine();
enum CommitState {
COMMIT_STATE_IDLE,
@@ -153,7 +153,7 @@ protected:
TextureState m_textureState;
ContextState m_contextState;
- DISALLOW_COPY_AND_ASSIGN(SchedulerStateMachine);
+ DISALLOW_COPY_AND_ASSIGN(CCSchedulerStateMachine);
};
}
@@ -11,7 +11,7 @@
namespace cc {
-// The SchedulerStateMachine decides how to coordinate main thread activites
+// The CCSchedulerStateMachine decides how to coordinate main thread activites
// like painting/running javascript with rendering and input activities on the
// impl thread.